@@ -16,6 +16,7 @@
 import abc
 import collections
 import copy
+import enum
 import io
 import json
 import logging
@@ -25,7 +26,7 @@ import zipfile
 import pkg_resources
 
 from sushy import exceptions
-from sushy.resources import mappings as res_maps
+from sushy.resources import constants
 from sushy.resources import oem
 from sushy import utils
 
@@ -269,18 +270,28 @@ class MappedField(Field):
         :param field: JSON field to fetch the value from. This can be either
             a string or a list of string. In the latter case, the value will
             be fetched from a nested object.
-        :param mapping: a mapping to take values from.
+        :param mapping: a mapping to take values from, a dictionary or
+            an enumeration.
         :param required: whether this field is required. Missing required,
             but not defaulted, fields result in MissingAttributeError.
         :param default: the default value to use when the field is missing.
             This value is not matched against the mapping.
         """
-        if not isinstance(mapping, collections.abc.Mapping):
-            raise TypeError("The mapping argument must be a mapping")
+        if isinstance(mapping, type) and issubclass(mapping, enum.Enum):
+            def adapter(value):
+                try:
+                    return mapping(value)
+                except ValueError:
+                    return None
+
+        elif isinstance(mapping, collections.abc.Mapping):
+            adapter = mapping.get
+        else:
+            raise TypeError("The mapping argument must be a mapping or "
+                            "an enumeration")
 
         super(MappedField, self).__init__(
-            field, required=required, default=default,
-            adapter=mapping.get)
+            field, required=required, default=default, adapter=adapter)
 
 
 class MappedListField(Field):
@@ -300,10 +311,20 @@ class MappedListField(Field):
             but not defaulted, fields result in MissingAttributeError.
         :param default: the default value to use when the field is missing.
         """
-        if not isinstance(mapping, collections.abc.Mapping):
-            raise TypeError("The mapping argument must be a mapping")
+        if isinstance(mapping, type) and issubclass(mapping, enum.Enum):
+            def adapter(value):
+                try:
+                    return mapping(value)
+                except ValueError:
+                    return None
 
-        self._mapping_adapter = mapping.get
+        elif isinstance(mapping, collections.abc.Mapping):
+            adapter = mapping.get
+        else:
+            raise TypeError("The mapping argument must be a mapping or "
+                            "an enumeration")
+
+        self._mapping_adapter = adapter
         super(MappedListField, self).__init__(
             field, required=required, default=default,
             adapter=lambda x: x)
@@ -339,8 +360,7 @@ class MessageListField(ListField):
     message = Field('Message')
     """Human readable message, if provided"""
 
-    severity = MappedField('Severity',
-                           res_maps.SEVERITY_VALUE_MAP)
+    severity = MappedField('Severity', constants.Severity)
     """Severity of the error"""
 
     resolution = Field('Resolution')
@@ -724,14 +744,7 @@ class ResourceBase(object, metaclass=abc.ABCMeta):
         return self._root
 
 
-class ResourceCollectionBase(ResourceBase, metaclass=abc.ABCMeta):
-
-    name = Field('Name')
-    """The name of the collection"""
-
-    members_identities = Field('Members', default=[],
-                               adapter=utils.get_members_identities)
-    """A tuple with the members identities"""
+class ResourceLinksBase(ResourceBase, metaclass=abc.ABCMeta):
 
     def __init__(self, connector, path, redfish_version=None, registries=None,
                  root=None):
@@ -747,12 +760,17 @@ class ResourceCollectionBase(ResourceBase, metaclass=abc.ABCMeta):
             used in any resource that needs registries to parse messages.
         :param root: Sushy root object. Empty for Sushy root itself.
         """
-        super(ResourceCollectionBase, self).__init__(
-            connector, path, redfish_version, registries, root=root)
+        super().__init__(connector, path, redfish_version, registries,
+                         root=root)
         LOG.debug('Received %(count)d member(s) for %(type)s %(path)s',
                   {'count': len(self.members_identities),
                    'type': self.__class__.__name__, 'path': self._path})
 
+    @property
+    @abc.abstractmethod
+    def members_identities(self):
+        """A sequence with members identities"""
+
     @property
     @abc.abstractmethod
     def _resource_type(self):
@@ -781,3 +799,13 @@ class ResourceCollectionBase(ResourceBase, metaclass=abc.ABCMeta):
         :returns: A list of ``_resource_type`` objects
         """
         return [self.get_member(id_) for id_ in self.members_identities]
+
+
+class ResourceCollectionBase(ResourceLinksBase):
+
+    name = Field('Name')
+    """The name of the collection"""
+
+    members_identities = Field('Members', default=[],
+                               adapter=utils.get_members_identities)
+    """A tuple with the members identities"""
