@@ -20,6 +20,7 @@ import sushy
 from sushy import exceptions
 from sushy.resources.chassis import chassis
 from sushy.resources.manager import manager
+from sushy.resources.system.network import adapter
 from sushy.resources.system import system
 from sushy.tests.unit import base
 
@@ -46,8 +47,7 @@ class ChassisTestCase(base.TestCase):
         self.assertEqual('Blade', self.chassis.name)
         self.assertEqual('Test description', self.chassis.description)
         self.assertEqual('45Z-2381', self.chassis.asset_tag)
-        self.assertEqual(sushy.CHASSIS_TYPE_BLADE,
-                         self.chassis.chassis_type)
+        self.assertEqual(sushy.ChassisType.BLADE, self.chassis.chassis_type)
         self.assertEqual('Contoso', self.chassis.manufacturer)
         self.assertEqual('SX1000', self.chassis.model)
         self.assertEqual('529QB9450R6', self.chassis.serial_number)
@@ -55,22 +55,21 @@ class ChassisTestCase(base.TestCase):
         self.assertEqual('166480-S23', self.chassis.part_number)
         self.assertEqual('FFFFFFFF-FFFF-FFFF-FFFF-FFFFFFFFFFFF',
                          self.chassis.uuid)
-        self.assertEqual(sushy.INDICATOR_LED_OFF,
+        self.assertEqual(sushy.IndicatorLED.OFF,
                          self.chassis.indicator_led)
-        self.assertEqual(sushy.POWER_STATE_ON,
-                         self.chassis.power_state)
-        self.assertEqual(sushy.STATE_ENABLED, self.chassis.status.state)
+        self.assertEqual(sushy.PowerState.ON, self.chassis.power_state)
+        self.assertEqual(sushy.State.ENABLED, self.chassis.status.state)
         self.assertEqual(44.45, self.chassis.height_mm)
         self.assertEqual(431.8, self.chassis.width_mm)
         self.assertEqual(711, self.chassis.depth_mm)
         self.assertEqual(15.31, self.chassis.weight_kg)
-        self.assertEqual(sushy.HEALTH_OK, self.chassis.status.health)
-        self.assertEqual(sushy.CHASSIS_INTRUSION_SENSOR_NORMAL,
+        self.assertEqual(sushy.Health.OK, self.chassis.status.health)
+        self.assertEqual(sushy.IntrusionSensor.NORMAL,
                          self.chassis.physical_security.intrusion_sensor)
         self.assertEqual(123,
                          self.chassis.physical_security.intrusion_sensor_number
                          )
-        self.assertEqual(sushy.CHASSIS_INTRUSION_SENSOR_RE_ARM_MANUAL,
+        self.assertEqual(sushy.IntrusionSensorReArm.MANUAL,
                          self.chassis.physical_security.intrusion_sensor_re_arm
                          )
 
@@ -79,26 +78,24 @@ class ChassisTestCase(base.TestCase):
 
         # Test that various types are returned correctly
         self.assertEqual('Blade', attributes.get('name'))
-        self.assertEqual(sushy.INDICATOR_LED_OFF,
+        self.assertEqual(sushy.IndicatorLED.OFF,
                          attributes.get('indicator_led'))
-        self.assertEqual(sushy.POWER_STATE_ON, attributes.get('power_state'))
-        self.assertEqual({'intrusion_sensor':
-                          sushy.CHASSIS_INTRUSION_SENSOR_NORMAL,
-                          'intrusion_sensor_number':
-                          123,
+        self.assertEqual(sushy.PowerState.ON, attributes.get('power_state'))
+        self.assertEqual({'intrusion_sensor': sushy.IntrusionSensor.NORMAL,
+                          'intrusion_sensor_number': 123,
                           'intrusion_sensor_re_arm':
-                          'manual re arm chassis intrusion sensor'},
+                          sushy.IntrusionSensorReArm.MANUAL},
                          attributes.get('physical_security'))
 
     def test_get_allowed_reset_chasis_values(self):
         # | GIVEN |
-        expected = {sushy.RESET_TYPE_POWER_CYCLE,
-                    sushy.RESET_TYPE_PUSH_POWER_BUTTON,
-                    sushy.RESET_TYPE_FORCE_ON, sushy.RESET_TYPE_NMI,
-                    sushy.RESET_TYPE_FORCE_RESTART,
-                    sushy.RESET_TYPE_GRACEFUL_RESTART, sushy.RESET_TYPE_ON,
-                    sushy.RESET_TYPE_FORCE_OFF,
-                    sushy.RESET_TYPE_GRACEFUL_SHUTDOWN}
+        expected = {sushy.ResetType.POWER_CYCLE,
+                    sushy.ResetType.PUSH_POWER_BUTTON,
+                    sushy.ResetType.FORCE_ON, sushy.ResetType.NMI,
+                    sushy.ResetType.FORCE_RESTART,
+                    sushy.ResetType.GRACEFUL_RESTART, sushy.ResetType.ON,
+                    sushy.ResetType.FORCE_OFF,
+                    sushy.ResetType.GRACEFUL_SHUTDOWN}
         # | WHEN |
         values = self.chassis.get_allowed_reset_chassis_values()
         # | THEN |
@@ -108,13 +105,16 @@ class ChassisTestCase(base.TestCase):
     def test_get_allowed_reset_chassis_values_for_no_values_set(self):
         # | GIVEN |
         self.chassis._actions.reset.allowed_values = []
-        expected = {sushy.RESET_TYPE_POWER_CYCLE,
-                    sushy.RESET_TYPE_PUSH_POWER_BUTTON,
-                    sushy.RESET_TYPE_FORCE_ON, sushy.RESET_TYPE_NMI,
-                    sushy.RESET_TYPE_FORCE_RESTART,
-                    sushy.RESET_TYPE_GRACEFUL_RESTART, sushy.RESET_TYPE_ON,
-                    sushy.RESET_TYPE_FORCE_OFF,
-                    sushy.RESET_TYPE_GRACEFUL_SHUTDOWN}
+        expected = {sushy.ResetType.POWER_CYCLE,
+                    sushy.ResetType.PUSH_POWER_BUTTON,
+                    sushy.ResetType.FORCE_ON, sushy.ResetType.NMI,
+                    sushy.ResetType.FORCE_RESTART,
+                    sushy.ResetType.GRACEFUL_RESTART, sushy.ResetType.ON,
+                    sushy.ResetType.FORCE_OFF,
+                    sushy.ResetType.GRACEFUL_SHUTDOWN,
+                    sushy.ResetType.SUSPEND,
+                    sushy.ResetType.RESUME,
+                    sushy.ResetType.PAUSE}
         # | WHEN |
         values = self.chassis.get_allowed_reset_chassis_values()
         # | THEN |
@@ -129,7 +129,7 @@ class ChassisTestCase(base.TestCase):
             exceptions.MissingActionError, 'action #Chassis.Reset')
 
     def test_reset_chassis(self):
-        self.chassis.reset_chassis(sushy.RESET_TYPE_GRACEFUL_RESTART)
+        self.chassis.reset_chassis(sushy.ResetType.GRACEFUL_RESTART)
         self.chassis._conn.post.assert_called_once_with(
             '/redfish/v1/Chassis/Blade1/Actions/Chassis.Reset',
             data={'ResetType': 'GracefulRestart'})
@@ -141,7 +141,7 @@ class ChassisTestCase(base.TestCase):
     def test_set_indicator_led(self):
         with mock.patch.object(
                 self.chassis, 'invalidate', autospec=True) as invalidate_mock:
-            self.chassis.set_indicator_led(sushy.INDICATOR_LED_BLINKING)
+            self.chassis.set_indicator_led(sushy.IndicatorLED.BLINKING)
             self.chassis._conn.patch.assert_called_once_with(
                 '/redfish/v1/Chassis/Blade1',
                 data={'IndicatorLED': 'Blinking'})
@@ -177,6 +177,49 @@ class ChassisTestCase(base.TestCase):
         self.assertEqual(
             '/redfish/v1/Systems/529QB9450R6', actual_systems[0].path)
 
+    def test_network_adapters(self):
+        self.conn.get.return_value.json.reset_mock()
+        with open('sushy/tests/unit/'
+                  'json_samples/network_adapter_collection.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+        actual_adapters = self.chassis.network_adapters
+        self.assertIsInstance(actual_adapters,
+                              adapter.NetworkAdapterCollection)
+        self.conn.get.return_value.json.assert_called_once_with()
+
+    def test_network_adapters_cached(self):
+        self.conn.get.return_value.json.reset_mock()
+        with open('sushy/tests/unit/'
+                  'json_samples/network_adapter_collection.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+        actual_adapters = self.chassis.network_adapters
+        self.conn.get.return_value.json.reset_mock()
+        self.assertIs(actual_adapters,
+                      self.chassis.network_adapters)
+        self.conn.get.return_value.json.assert_not_called()
+
+    def test_network_adapters_refresh(self):
+        with open('sushy/tests/unit/'
+                  'json_samples/network_adapter_collection.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+        adapters = self.chassis.network_adapters
+        self.assertIsInstance(adapters, adapter.NetworkAdapterCollection)
+
+        with open('sushy/tests/unit/'
+                  'json_samples/chassis.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+
+        self.chassis.invalidate()
+        self.chassis.refresh(force=False)
+
+        self.assertTrue(adapters._is_stale)
+
+        with open('sushy/tests/unit/'
+                  'json_samples/network_adapter_collection.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+        self.assertIsInstance(self.chassis.network_adapters,
+                              adapter.NetworkAdapterCollection)
+
 
 class ChassisCollectionTestCase(base.TestCase):
 
