@@ -144,7 +144,7 @@ class ConnectorMethodsTestCase(base.TestCase):
 
     def test_set_http_session_auth(self):
         self.conn.set_http_session_auth('hash-token')
-        self.assertTrue('X-Auth-Token' in self.conn._session.headers)
+        self.assertIn('X-Auth-Token', self.conn._session.headers)
         self.assertEqual(
             'hash-token', self.conn._session.headers['X-Auth-Token'])
 
@@ -220,6 +220,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._session.headers['X-Auth-Token'] = 'asdf1234'
         expected_headers = self.headers.copy()
         expected_headers['OData-Version'] = '4.0'
+        expected_headers['Content-Type'] = 'application/json'
         self.conn._op('POST', path='fake/path', headers=self.headers,
                       data=self.data)
         self.request.assert_called_once_with(
@@ -371,6 +372,18 @@ class ConnectorOpTestCase(base.TestCase):
         exc = cm.exception
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
 
+    def test_access_error_without_auth(self):
+        self.conn._auth = None
+
+        self.request.return_value.status_code = http_client.FORBIDDEN
+        self.request.return_value.json.side_effect = ValueError('no json')
+
+        with self.assertRaisesRegex(exceptions.AccessError,
+                                    'unknown error') as cm:
+            self.conn._op('GET', 'http://foo.bar')
+        exc = cm.exception
+        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
+
     @mock.patch.object(connector.LOG, 'debug', autospec=True)
     def test_access_error_service_session(self, mock_log):
         self.conn._auth.can_refresh_session.return_value = False
@@ -386,8 +399,8 @@ class ConnectorOpTestCase(base.TestCase):
             'HTTP GET of SessionService failed %s, '
             'this is expected prior to authentication', 'HTTP GET '
             'http://redfish/v1/SessionService returned code '
-            'HTTPStatus.FORBIDDEN. unknown error Extended information: '
-            'none')
+            '%s. unknown error Extended information: '
+            'none' % http_client.FORBIDDEN)
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
 
     def test_blocking_no_location_header(self):
